# batgrl - badass terminal graphics library

Create games:

![Tetris](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/game.png)

Simulations:

![Simulation](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/simulation.png)

Or entire feature-filled applications:

![Application](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/application.png)

[See it in action](https://youtu.be/q1K6_P1COTI)

[Read the docs](https://salt-die.github.io/batgrl/index.html)
